==> tasks-v1.8.8.zip: tasks/messages/hu/base.php <==
<?php

return [
    '1 Day before' => '1 nappal előtte',
    '1 Month before' => '1 hónappal előtte',
    '1 Week before' => '1 héttel előtte',
    '2 Days before' => '2 nappal előtte',
    '2 Weeks before' => '2 héttel előtte',
    '3 Weeks before' => '3 héttel előtte',
    '<strong>Assigned users</strong> are allowed to process this task.' => 'Csak <strong>kijelölt felhasználók</strong> dolgozhatnak ezen a feladaton.',
    '<strong>Confirm</strong> task deletion' => '<strong>Erősítsd meg</strong> a feladat törlését',
    '<strong>Create</strong> task list' => 'Feladatlista <strong>létrehozása</strong>',
    '<strong>Edit</strong> task' => 'Feladat <strong>szerkesztése</strong>',
    '<strong>Edit</strong> task list' => 'Feladatlista <strong>szerkesztése</strong>',
    '<strong>New</strong> Task' => '<strong>Új</strong> feladat',
    '<strong>Task</strong> Overview' => '<strong>Feladat</strong> áttekintése',
    '<strong>Tasks</strong>' => '<strong>Feladatok</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Feladatok</strong> modul konfigurációja',
    '<strong>Your</strong> tasks' => '<strong>Saját</strong> feladataid',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'A widget egy hírfolyam oldalsávjához hozzáadott elem. Ebben az esetben a felhasználóknak rövid áttekintést nyújtanak feladataikról.',
    'Accept Task' => 'Feladat elfogadása',
    'Add Deadline to space calendar' => 'Határidő hozzáadása a közösség naptárához',
    'Add checkpoint...' => 'Ellenőrző pont hozzáadása...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Adjon hozzá ellenőrzőpontokat a feladathoz, hogy kiemelje a végrehajtásához szükséges egyes lépéseket.',
    'Add entry to main navigation' => 'Bejegyzés hozzáadása a fő navigációhoz',
    'Add reminder' => 'Emlékeztető hozzáadása',
    'Add responsible users' => 'Felelős felhasználók hozzáadása',
    'Add schedule to the space calendar' => 'Ütemezés hozzáadása a közösség naptárához',
    'Add task' => 'Feladat hozzáadása',
    'Add to space calendar' => 'Hozzáadás a közösség naptárához',
    'Additional options' => 'További beállítások',
    'All Day' => 'Egész napos',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Lehetővé teszi a felhasználó számára, hogy új feladatokat hozzon létre. A felhasználó csak a saját feladatait tudja szerkeszteni vagy törölni.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Lehetővé teszi a felhasználó számára feladatok és listák létrehozását, törlését és szerkesztését, valamint feladatok és listák rendezését',
    'Allows the user to process unassigned tasks' => 'Lehetővé teszi a felhasználó számára a ki nem adott feladatok feldolgozását',
    'Already requested' => 'Már jött ilyen kérés',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Ezen a feladaton bárki dolgozhat, aki "Ki nem adott feladatok feldolgozása" engedéllyel rendelkezik',
    'Anyone can work on this task!' => 'Bárki dolgozhat ezen a feladaton!',
    'Assign myself' => 'Hozzárendelem magam',
    'Assign users' => 'Felhasználók kijelölése',
    'Assigned' => 'Kijelölve',
    'Assigned users' => 'Hozzárendelt felhasználók',
    'Assignment' => 'Kijelölés',
    'Assignments:' => 'Kiadott feladatok:',
    'At least 1 Hour before' => 'Legalább 1 órával előtte',
    'At least 2 Hours before' => 'Legalább 2 órával előtte',
    'Attachments' => 'Mellékletek',
    'Begin Task' => 'Feladat elkezdése',
    'Checklist Items' => 'Ellenőrző lista elemei',
    'Checklist:' => 'Ellenőrzőlista',
    'Checkpoints' => 'Ellenőrzési pontok',
    'Choose if you want the module to appear in the main navigation.' => 'Válassza ki, ha szeretné, hogy a modul megjelenjen a fő navigációban.',
    'Close' => 'Bezárás',
    'Color' => 'Szín',
    'Completed' => 'Befejezve',
    'Completed lists' => 'Kész listák',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfigurálja a Feladatok modult, hogy megfeleljen sajátos követelményeinek és igényeinek. Megadhat egyedi beállításokat és például eldöntheti, hogy megjelenjen-e egy widget.',
    'Continue Review' => 'Átnézés folytatása',
    'Create tasks' => 'Feladatok létrehozása',
    'Created by me' => 'Általam létrehozva',
    'Date' => 'Dátum',
    'Deadline at' => 'Határidő:',
    'Deadline: ' => 'Határidő:',
    'Delete' => 'Törlés',
    'Delete list' => 'Lista törlése',
    'Description' => 'Leírás',
    'Do not remind' => 'Ne emlékeztessen',
    'Do you really want to delete this task?' => 'Tényleg törölni akarod ezt a feladatot?',
    'Don\'t add to calendar' => 'Ne adja hozzá a naptárhoz',
    'Drag entry' => 'Bejegyzés mozgatása',
    'Edit' => 'Szerkesztés',
    'Edit item (empty field will be removed)...' => 'Elem szerkesztése (az üres mezők törölve lesznek)...',
    'Edit list' => 'Lista szerkesztése',
    'End' => 'Befejezés',
    'End Date' => 'Befejezés dátuma',
    'End Time' => 'Befejezés időpontja',
    'End date' => 'Befejezési idő',
    'End time must be after start time!' => 'A befejezés időpontjának a kezdés időpontja utáni időpontnak kell lennie!',
    'Extend deadline request' => 'Határidő meghosszabbításának kérése',
    'Filter' => 'Szűrés',
    'Filter by status' => 'Szűrés állapot szerint',
    'Filter by title' => 'Szűrés cím szerint',
    'Filter tasks' => 'Feladatok szűrése',
    'Finish Task' => 'Feladat befejezése',
    'General' => 'Általános',
    'General Settings' => 'Általános beállítások',
    'Hide this list once all tasks are completed' => 'A lista elrejtése, ha minden feladat befejeződött.',
    'I\'m assigned' => 'Én vagyok kijelölve a feladatra',
    'I\'m responsible' => 'Én vagyok a felelőse',
    'If empty any user can complete the task.' => 'Ha üres, bármelyik felhasználó elvégezheti a feladatot.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ha nincs kiválasztva hozzárendelt felhasználó, akkor a kiadatlan feladatok elvégzésére jogosult minden tag dolgozhat a feladaton.',
    'In Progress' => 'Folyamatban',
    'In Review' => 'Ellenőrzés alatt',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Abban az esetben, ha az átnézés opció aktív, egy <strong>felelős felhasználónak</strong> kell a feladatot átnéznie, és el kell utasítania vagy jóvá kell hagynia azt a feladat a befejezése előtt.',
    'Invalid task list selection.' => 'Érvénytelen feladatlistaválasztás.',
    'Let Task Review' => 'Feladat átnézésének engedése',
    'Main Navigation' => 'Fő navigáció',
    'Manage tasks' => 'Feladatok kezelése',
    'Maximum number of entries in widget' => 'Maximális számú bejegyzés a widgetben',
    'Module Widget' => 'Widget modul',
    'New list or search' => 'Új lista vagy keresés',
    'No Scheduling set for this Task' => 'Ez a feladat nincs ütemezve',
    'No pending tasks found' => 'Nincsenek függőben lévő feladatok',
    'No results found for the given filter.' => 'Nincs találat a megadott szűrőre.',
    'Open Task' => 'Feladat megnyitása',
    'Other Tasks' => 'Egyéb feladatok',
    'Overdue' => 'A határidő lejárt',
    'Overview' => 'Áttekintés',
    'Parent Task' => 'Forrás feladat',
    'Pending' => 'Függőben',
    'Pending Review' => 'Ellenőrzésre vár',
    'Process unassigned tasks' => 'Ki nem adott feladatok elvégzése',
    'Ready For Review' => 'Készen áll az átnézésre',
    'Receive Notifications for Task Reminder.' => 'Értesítések fogadása a feladat-emlékeztetőkhöz',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Értesítések fogadása feladatokhoz (határidő emlékeztetők, állapotváltozások ...).',
    'Reject Task' => 'Feladat elutasítása',
    'Remind Mode' => 'Emlékeztető mód',
    'Reminder' => 'Emlékeztető',
    'Reminder sent' => 'Emlékeztető elküldve',
    'Reminders' => 'Emlékeztetők',
    'Request extension' => 'Hosszabbítás kérése',
    'Request sent' => 'Kérés elküldve',
    'Reset Task' => 'Feladat visszaállítása alaphelyzetbe',
    'Responsible' => 'Felelős',
    'Responsible users' => 'Felelős felhasználók',
    'Review by responsible user required' => 'A felelős felhasználónak át kell néznie a feladatot',
    'Scheduling' => 'Ütemezés',
    'Show widget in Spaces' => 'Modul megjelenítése a Közösségben',
    'Show widget on Dashboard' => 'Widget megjelenítése a Hírfolyamban',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mutasson {count} több befejezett {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Rendezési sorrend',
    'Sort order' => 'Sorrend beállítása',
    'Spaces' => 'Közösségek',
    'Start' => 'Kezdés',
    'Start Date' => 'Kezdés dátuma',
    'Start Time' => 'Kezdés időpontja',
    'Start date' => 'Kezdési idő',
    'Starting at' => 'Kezdés innen',
    'Status' => 'Állapot',
    'Task' => 'Feladat',
    'Task List' => 'Feladatlista',
    'Task Users have been notified' => 'A feladathoz tartozó felhasználók értesítve lettek',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'A {task} feladat a {spaceName} közösségben ekkor fejeződik be: {dateTime}',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'A {task} feladat a {spaceName} közösségben ekkor kezdődik: {dateTime}',
    'Tasks' => 'Feladatok',
    'Tasks: Reminder' => 'Feladatok: emlékeztető',
    'This task can only be processed by assigned and responsible users.' => 'Ezen a feladaton csak a hozzárendelt és felelős felhasználók dolgozhatnak.',
    'This task requires to be reviewed by a responsible' => 'Ezt a feladatot egy felelős felhasználónak kell átnéznie',
    'Time Zone' => 'Időzóna',
    'Title' => 'Cím',
    'Title and Color' => 'Cím és szín',
    'Title of your task list' => 'A feladatlista címe',
    'Today' => 'Ma',
    'Unsorted' => 'Nincs rendezve',
    'View Online' => 'Megtekintés online',
    'You are assigned!' => 'Ki lettél jelölve!',
    'You are responsible!' => 'Te vagy a felelős ezért a feladatért!',
    'You have insufficient permissions to perform that operation!' => 'Nem rendelkezel elegendő jogosultsággal a művelet elvégzéséhez!',
    'Your Reminder for task {task}' => 'A te emlékeztetőd a {task} feladathoz',
    'ending Review' => 'Ellenőrzés befejezése',
    'view all' => 'mindent mutat',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count} nap maradt',
    '{displayName} is assigned to this task' => '{displayName} ki lett jelölve erre a feladatra',
    '{displayName} is responsible for this task' => '{displayName} a felelős ezért a feladatért',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} kijelölt téged, mint a {task} feladat felelősét a {spaceName} közösségben.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ki lett jelölve a {task} feladatra a {spaceName} közösségben.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} teljesítette {task} feladatot ebben a közösségben {spaceName}.',
    '{userName} completed task {task}.' => '{userName} elvégezte a feladatot {task}.',
    '{userName} finished task {task}.' => '{userName} befejezte a {task} feladatot.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} módosította a {task} feladat teljesítésének határidejét a {spaceName} közösségben.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} újra megnyitotta a {task} feladatot a {spaceName} közösségben.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} elutasította a {task} feladatot a {spaceName} közösségben, mint befejezetlen feladatot.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} a {task} feladatot a {spaceName} közösségben befejezettként jelölte meg.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} a határidő meghosszabbítását kéri a {task} feladathoz a {spaceName} közösségben.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} arra kér, hogy ellenőrizd a {task} feladatot a {spaceName} közösségben.',
    '{userName} reset task {task}.' => '{userName} visszaállította a feladatot alaphelyzetbe {task}.',
    '{userName} reviewed task {task}.' => '{userName} átnézte a feladatot {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} dolgozni kezdett a {task} feladaton a {spaceName} közösségben.',
    '{userName} works on task {task}.' => '{userName} dolgozik a feladaton {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/hu/base.php <==
<?php

return [
    '1 Day before' => '1 nappal előtte',
    '1 Month before' => '1 hónappal előtte',
    '1 Week before' => '1 héttel előtte',
    '2 Days before' => '2 nappal előtte',
    '2 Weeks before' => '2 héttel előtte',
    '3 Weeks before' => '3 héttel előtte',
    '<strong>Assigned users</strong> are allowed to process this task.' => 'Csak <strong>kijelölt felhasználók</strong> dolgozhatnak ezen a feladaton.',
    '<strong>Confirm</strong> task deletion' => '<strong>Erősítsd meg</strong> a feladat törlését',
    '<strong>Create</strong> task list' => 'Feladatlista <strong>létrehozása</strong>',
    '<strong>Edit</strong> task' => 'Feladat <strong>szerkesztése</strong>',
    '<strong>Edit</strong> task list' => 'Feladatlista <strong>szerkesztése</strong>',
    '<strong>New</strong> Task' => '<strong>Új</strong> feladat',
    '<strong>Task</strong> Overview' => '<strong>Feladat</strong> áttekintése',
    '<strong>Tasks</strong>' => '<strong>Feladatok</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Feladatok</strong> modul konfigurációja',
    '<strong>Your</strong> tasks' => '<strong>Saját</strong> feladataid',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'A widget egy hírfolyam oldalsávjához hozzáadott elem. Ebben az esetben a felhasználóknak rövid áttekintést nyújtanak feladataikról.',
    'Accept Task' => 'Feladat elfogadása',
    'Add Deadline to space calendar' => 'Határidő hozzáadása a közösség naptárához',
    'Add checkpoint...' => 'Ellenőrző pont hozzáadása...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Adjon hozzá ellenőrzőpontokat a feladathoz, hogy kiemelje a végrehajtásához szükséges egyes lépéseket.',
    'Add entry to main navigation' => 'Bejegyzés hozzáadása a fő navigációhoz',
    'Add reminder' => 'Emlékeztető hozzáadása',
    'Add responsible users' => 'Felelős felhasználók hozzáadása',
    'Add schedule to the space calendar' => 'Ütemezés hozzáadása a közösség naptárához',
    'Add task' => 'Feladat hozzáadása',
    'Add to space calendar' => 'Hozzáadás a közösség naptárához',
    'Additional options' => 'További beállítások',
    'All Day' => 'Egész napos',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Lehetővé teszi a felhasználó számára, hogy új feladatokat hozzon létre. A felhasználó csak a saját feladatait tudja szerkeszteni vagy törölni.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Lehetővé teszi a felhasználó számára feladatok és listák létrehozását, törlését és szerkesztését, valamint feladatok és listák rendezését',
    'Allows the user to process unassigned tasks' => 'Lehetővé teszi a felhasználó számára a ki nem adott feladatok feldolgozását',
    'Already requested' => 'Már jött ilyen kérés',
    'Assign myself' => 'Hozzárendelem magam',
    'Assign users' => 'Felhasználók kijelölése',
    'Assigned users' => 'Hozzárendelt felhasználók',
    'Assignment' => 'Kijelölés',
    'At least 1 Hour before' => 'Legalább 1 órával előtte',
    'At least 2 Hours before' => 'Legalább 2 órával előtte',
    'Attachments' => 'Mellékletek',
    'Begin Task' => 'Feladat elkezdése',
    'Checklist Items' => 'Ellenőrző lista elemei',
    'Checklist:' => 'Ellenőrzőlista',
    'Checkpoints' => 'Ellenőrzési pontok',
    'Choose if you want the module to appear in the main navigation.' => 'Válassza ki, ha szeretné, hogy a modul megjelenjen a fő navigációban.',
    'Close' => 'Bezárás',
    'Color' => 'Szín',
    'Completed' => 'Befejezve',
    'Completed lists' => 'Kész listák',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfigurálja a Feladatok modult, hogy megfeleljen sajátos követelményeinek és igényeinek. Megadhat egyedi beállításokat és például eldöntheti, hogy megjelenjen-e egy widget.',
    'Continue Review' => 'Átnézés folytatása',
    'Create tasks' => 'Feladatok létrehozása',
    'Created by me' => 'Általam létrehozva',
    'Date' => 'Dátum',
    'Deadline: ' => 'Határidő:',
    'Delete' => 'Törlés',
    'Delete list' => 'Lista törlése',
    'Description' => 'Leírás',
    'Do not remind' => 'Ne emlékeztessen',
    'Do you really want to delete this task?' => 'Tényleg törölni akarod ezt a feladatot?',
    'Don\'t add to calendar' => 'Ne adja hozzá a naptárhoz',
    'Edit' => 'Szerkesztés',
    'Edit item (empty field will be removed)...' => 'Elem szerkesztése (az üres mezők törölve lesznek)...',
    'Edit list' => 'Lista szerkesztése',
    'End' => 'Befejezés',
    'End Date' => 'Befejezés dátuma',
    'End Time' => 'Befejezés időpontja',
    'End date' => 'Befejezési idő',
    'End time must be after start time!' => 'A befejezés időpontjának a kezdés időpontja utáni időpontnak kell lennie!',
    'Extend deadline request' => 'Határidő meghosszabbításának kérése',
    'Filter' => 'Szűrés',
    'Filter by status' => 'Szűrés állapot szerint',
    'Filter by title' => 'Szűrés cím szerint',
    'Filter tasks' => 'Feladatok szűrése',
    'Finish Task' => 'Feladat befejezése',
    'General' => 'Általános',
    'General Settings' => 'Általános beállítások',
    'Hide this list once all tasks are completed' => 'A lista elrejtése, ha minden feladat befejeződött.',
    'I\'m assigned' => 'Én vagyok kijelölve a feladatra',
    'I\'m responsible' => 'Én vagyok a felelőse',
    'If empty any user can complete the task.' => 'Ha üres, bármelyik felhasználó elvégezheti a feladatot.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ha nincs kiválasztva hozzárendelt felhasználó, akkor a kiadatlan feladatok elvégzésére jogosult minden tag dolgozhat a feladaton.',
    'In Progress' => 'Folyamatban',
    'In Review' => 'Ellenőrzés alatt',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Abban az esetben, ha az átnézés opció aktív, egy <strong>felelős felhasználónak</strong> kell a feladatot átnéznie, és el kell utasítania vagy jóvá kell hagynia azt a feladat a befejezése előtt.',
    'Invalid task list selection.' => 'Érvénytelen feladatlistaválasztás.',
    'Let Task Review' => 'Feladat átnézésének engedése',
    'Main Navigation' => 'Fő navigáció',
    'Manage tasks' => 'Feladatok kezelése',
    'Maximum number of entries in widget' => 'Maximális számú bejegyzés a widgetben',
    'Module Widget' => 'Widget modul',
    'New list or search' => 'Új lista vagy keresés',
    'No Scheduling set for this Task' => 'Ez a feladat nincs ütemezve',
    'No pending tasks found' => 'Nincsenek függőben lévő feladatok',
    'No results found for the given filter.' => 'Nincs találat a megadott szűrőre.',
    'Open Task' => 'Feladat megnyitása',
    'Other Tasks' => 'Egyéb feladatok',
    'Overdue' => 'A határidő lejárt',
    'Overview' => 'Áttekintés',
    'Parent Task' => 'Forrás feladat',
    'Pending' => 'Függőben',
    'Pending Review' => 'Ellenőrzésre vár',
    'Process unassigned tasks' => 'Ki nem adott feladatok elvégzése',
    'Ready For Review' => 'Készen áll az átnézésre',
    'Receive Notifications for Task Reminder.' => 'Értesítések fogadása a feladat-emlékeztetőkhöz',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Értesítések fogadása feladatokhoz (határidő emlékeztetők, állapotváltozások ...).',
    'Reject Task' => 'Feladat elutasítása',
    'Remind Mode' => 'Emlékeztető mód',
    'Reminder' => 'Emlékeztető',
    'Reminder sent' => 'Emlékeztető elküldve',
    'Reminders' => 'Emlékeztetők',
    'Request extension' => 'Hosszabbítás kérése',
    'Request sent' => 'Kérés elküldve',
    'Reset Task' => 'Feladat visszaállítása alaphelyzetbe',
    'Responsible' => 'Felelős',
    'Responsible users' => 'Felelős felhasználók',
    'Review by responsible user required' => 'A felelős felhasználónak át kell néznie a feladatot',
    'Scheduling' => 'Ütemezés',
    'Show widget in Spaces' => 'Modul megjelenítése a Közösségben',
    'Show widget on Dashboard' => 'Widget megjelenítése a Hírfolyamban',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mutasson {count} több befejezett {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Rendezési sorrend',
    'Sort order' => 'Sorrend beállítása',
    'Spaces' => 'Közösségek',
    'Start' => 'Kezdés',
    'Start Date' => 'Kezdés dátuma',
    'Start Time' => 'Kezdés időpontja',
    'Start date' => 'Kezdési idő',
    'Starting at' => 'Kezdés innen',
    'Status' => 'Állapot',
    'Task' => 'Feladat',
    'Task List' => 'Feladatlista',
    'Task Users have been notified' => 'A feladathoz tartozó felhasználók értesítve lettek',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'A {task} feladat a {spaceName} közösségben ekkor fejeződik be: {dateTime}',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'A {task} feladat a {spaceName} közösségben ekkor kezdődik: {dateTime}',
    'Tasks' => 'Feladatok',
    'Tasks: Reminder' => 'Feladatok: emlékeztető',
    'This task requires to be reviewed by a responsible' => 'Ezt a feladatot egy felelős felhasználónak kell átnéznie',
    'Time Zone' => 'Időzóna',
    'Title' => 'Cím',
    'Title and Color' => 'Cím és szín',
    'Title of your task list' => 'A feladatlista címe',
    'Today' => 'Ma',
    'Unsorted' => 'Nincs rendezve',
    'View Online' => 'Megtekintés online',
    'You have insufficient permissions to perform that operation!' => 'Nem rendelkezel elegendő jogosultsággal a művelet elvégzéséhez!',
    'Your Reminder for task {task}' => 'A te emlékeztetőd a {task} feladathoz',
    'view all' => 'mindent mutat',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count} nap maradt',
    '{displayName} is assigned to this task' => '{displayName} ki lett jelölve erre a feladatra',
    '{displayName} is responsible for this task' => '{displayName} a felelős ezért a feladatért',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} kijelölt téged, mint a {task} feladat felelősét a {spaceName} közösségben.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ki lett jelölve a {task} feladatra a {spaceName} közösségben.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} teljesítette {task} feladatot ebben a közösségben {spaceName}.',
    '{userName} completed task {task}.' => '{userName} elvégezte a feladatot {task}.',
    '{userName} finished task {task}.' => '{userName} befejezte a {task} feladatot.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} módosította a {task} feladat teljesítésének határidejét a {spaceName} közösségben.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} újra megnyitotta a {task} feladatot a {spaceName} közösségben.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} elutasította a {task} feladatot a {spaceName} közösségben, mint befejezetlen feladatot.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} a {task} feladatot a {spaceName} közösségben befejezettként jelölte meg.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} a határidő meghosszabbítását kéri a {task} feladathoz a {spaceName} közösségben.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} arra kér, hogy ellenőrizd a {task} feladatot a {spaceName} közösségben.',
    '{userName} reset task {task}.' => '{userName} visszaállította a feladatot alaphelyzetbe {task}.',
    '{userName} reviewed task {task}.' => '{userName} átnézte a feladatot {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} dolgozni kezdett a {task} feladaton a {spaceName} közösségben.',
    '{userName} works on task {task}.' => '{userName} dolgozik a feladaton {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
